
# Slot: has_member


the values of the slot is multivalued with at least one member satisfying the condition

URI: [linkml:has_member](https://w3id.org/linkml/has_member)


## Domain and Range

None &#8594;  <sub>0..1</sub> [AnonymousSlotExpression](AnonymousSlotExpression.md)

## Parents

 *  is_a: [list_value_specification_constant](list_value_specification_constant.md)

## Children


## Used by

 * [AnonymousSlotExpression](AnonymousSlotExpression.md)
 * [SlotDefinition](SlotDefinition.md)
 * [SlotExpression](SlotExpression.md)
